@@ -34,7 +34,7 @@ class DAppClient:
         self.api_key = api_key
         self.broadcast_url = broadcast_url
         self.transport = AIOHTTPTransport(
-            url=graphql_url, headers={"API-KEY": api_key})
+            url=graphql_url, headers=self.__headers(is_json=False))
 
     async def query(self, queries: List[DocumentNode]) -> List[Any]:
         results = []
@@ -55,15 +55,18 @@ class DAppClient:
 
         async with aiohttp.ClientSession(timeout=timeout) as session:
             for query in queries:
-                async with session.post(self.broadcast_url, json=query.dict(), headers=self.__headers()) as resp:
+                async with session.post(self.broadcast_url, json=query.dict(), headers=self.__headers(is_json=True)) as resp:
                     results.append(await self.__parse_response(resp))
 
         return results
 
-    def __headers(self):
-        headers = {
-            'Content-Type': 'application/json',
-        }
+    def __headers(self, is_json):
+        headers = {}
+
+        if is_json:
+            headers = {
+                'Content-Type': 'application/json',
+            }
 
         if self.api_key:
             headers['API-KEY'] = self.api_key
